@@ -1,24 +1,21 @@
-# @(#)$Ident: Anchor.pm 2013-05-16 14:18 pjf ;
-
 package HTML::FormWidgets::Anchor;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(config fhelp href imgclass target) );
+__PACKAGE__->mk_accessors( qw( config fhelp href imgclass target ) );
 
 sub init {
    my ($self, $args) = @_;
 
-   $self->class   ( q(anchor_button fade) );
-   $self->config  ( undef     );
-   $self->fhelp   ( ''        );
-   $self->href    ( undef     );
-   $self->imgclass( undef     );
-   $self->target  ( undef     );
-   $self->tiptype ( q(normal) );
+   $self->class   ( 'anchor_button fade' );
+   $self->config  ( undef    );
+   $self->fhelp   ( q()      );
+   $self->href    ( undef    );
+   $self->imgclass( undef    );
+   $self->target  ( undef    );
+   $self->tiptype ( 'normal' );
    return;
 }
 
@@ -28,17 +25,19 @@ sub render_field {
    $self->id and $self->config
       and $self->add_literal_js( 'anchors', $self->id, $self->config );
 
+   my $src  = 'http:' eq (substr $self->text, 0, 5)
+            ? $self->text : ($self->options->{assets} // q()).$self->text;
    my $html = $self->imgclass
             ? $self->text
             ? $hacc->img ( { alt   => $self->fhelp,
                              class => $self->imgclass,
-                             src   => $self->text } )
+                             src   => $src } )
             : $hacc->span( { class => $self->imgclass } )
-            : $self->text || $self->loc( q(link) );
+            : $self->text || $self->loc( 'link' );
 
    $self->href or return $html; delete $args->{name};
 
-   $args->{class} = $self->class; $args->{href} = $self->href;
+   $args->{class} = $self->class; $args->{href} = $self->uri_for( $self->href );
 
    defined $self->target and $args->{target} = $self->target;
 
