@@ -1,13 +1,10 @@
-# @(#)$Ident: List.pm 2013-05-16 14:19 pjf ;
-
 package HTML::FormWidgets::List;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(config data item_class ordered) );
+__PACKAGE__->mk_accessors( qw( config data item_class ordered ) );
 
 my $NBSP = '&#160;';
 
@@ -15,7 +12,7 @@ sub init {
    my ($self, $args) = @_;
 
    $self->config    ( {} );
-   $self->class     ( q(plain) );
+   $self->class     ( 'plain' );
    $self->data      ( [] );
    $self->item_class( undef );
    $self->ordered   ( 0 );
@@ -32,14 +29,14 @@ sub render_field {
          $js_args->{ $_ } = '"'.$self->config->{ $_ }.'"';
       }
 
-      $self->add_literal_js( q(lists), $self->id, $js_args );
+      $self->add_literal_js( 'lists', $self->id, $js_args );
    }
 
    my $item_args = $self->item_class ? { class => $self->item_class } : {} ;
 
    for my $item (@{ $data }) {
       $html .= $hacc->li( $item_args,
-                          $self->inflate( $item->{content} || $NBSP ) );
+                          $self->inflate( $item->{content} // $NBSP ) );
    }
 
    $args = { class => $self->class }; $self->id and $args->{id} = $self->id;
