@@ -1,13 +1,10 @@
-# @(#)$Ident: Menu.pm 2013-05-16 14:22 pjf ;
-
 package HTML::FormWidgets::Menu;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(data select spacer) );
+__PACKAGE__->mk_accessors( qw( data select spacer ) );
 
 my $NBSP = '&#160;';
 
