@@ -1,13 +1,10 @@
-# @(#)$Ident: Paragraphs.pm 2013-05-16 14:21 pjf ;
-
 package HTML::FormWidgets::Paragraphs;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(column_class data hclass) );
+__PACKAGE__->mk_accessors( qw( column_class data hclass ) );
 
 sub init {
    my ($self, $args) = @_;
