@@ -1,13 +1,10 @@
-# @(#)$Ident: PopupMenu.pm 2013-05-16 14:21 pjf ;
-
 package HTML::FormWidgets::PopupMenu;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(classes labels values) );
+__PACKAGE__->mk_accessors( qw( classes labels values ) );
 
 sub init {
    my ($self, $args) = @_;
